# bolt

[![Build Status](https://travis-ci.org/abantos/bolt.svg?branch=master)](https://travis-ci.org/abantos/bolt)

A task automation tool (similart to grunt) for Python.

[Bolt documentation](http://bolt-task-automation.readthedocs.io)
